[SCM] libav/experimental: Implement audio cutoff frequency to the vorbis encoder. Patch by Justin Ruggles jruggle earthlink net.
siretart at users.alioth.debian.org
siretart at users.alioth.debian.org
Sun Jun 30 15:46:03 UTC 2013
The following commit has been merged in the experimental branch:
commit 13c71451350071888b5d690f9d48cd316e0d4aed
Author: Justin Ruggles <jruggle at earthlink.net>
Date: Sat Jan 21 17:09:23 2006 +0000
Implement audio cutoff frequency to the vorbis encoder.
Patch by Justin Ruggles jruggle earthlink net.
Originally committed as revision 4877 to svn://svn.ffmpeg.org/ffmpeg/trunk
diff --git a/libavcodec/oggvorbis.c b/libavcodec/oggvorbis.c
index 80ed07d..56fa247 100644
--- a/libavcodec/oggvorbis.c
+++ b/libavcodec/oggvorbis.c
@@ -29,25 +29,35 @@ typedef struct OggVorbisContext {
static int oggvorbis_init_encoder(vorbis_info *vi, AVCodecContext *avccontext) {
+ double cfreq;
if(avccontext->flags & CODEC_FLAG_QSCALE) {
- return vorbis_encode_init_vbr(vi, avccontext->channels,
+ /* variable bitrate */
+ if(vorbis_encode_setup_vbr(vi, avccontext->channels,
avccontext->sample_rate,
- avccontext->global_quality / (float)FF_QP2LAMBDA);
- }
+ avccontext->global_quality / (float)FF_QP2LAMBDA))
+ return -1;
+ } else {
+ /* constant bitrate */
+ if(vorbis_encode_setup_managed(vi, avccontext->channels,
+ avccontext->sample_rate, -1, avccontext->bit_rate, -1))
+ return -1;
+
#ifdef OGGVORBIS_VBR_BY_ESTIMATE
- /* variable bitrate by estimate */
+ /* variable bitrate by estimate */
+ if(vorbis_encode_ctl(vi, OV_ECTL_RATEMANAGE_AVG, NULL))
+ return -1;
+#endif
+ }
- return (vorbis_encode_setup_managed(vi, avccontext->channels,
- avccontext->sample_rate, -1, avccontext->bit_rate, -1) ||
- vorbis_encode_ctl(vi, OV_ECTL_RATEMANAGE_AVG, NULL) ||
- vorbis_encode_setup_init(vi)) ;
-#else
- /* constant bitrate */
+ /* cutoff frequency */
+ if(avccontext->cutoff > 0) {
+ cfreq = avccontext->cutoff / 1000.0;
+ if(vorbis_encode_ctl(vi, OV_ECTL_LOWPASS_SET, &cfreq))
+ return -1;
+ }
- return vorbis_encode_init(vi, avccontext->channels,
- avccontext->sample_rate, -1, avccontext->bit_rate, -1) ;
-#endif
+ return vorbis_encode_setup_init(vi);
}
static int oggvorbis_encode_init(AVCodecContext *avccontext) {
--
Libav/FFmpeg packaging
More information about the pkg-multimedia-commits
mailing list